@@ -19,8 +19,9 @@ class HashedAuthenticator(object):
   def create_query_string(cls, options):
     combined_options = []
     for key, value in options.iteritems():
-      combined_options.append(key + '=' + str(value))
-    return '&'.join(combined_options) 
+      sval = str(value).lower() if isinstance(value, bool)  else str(value)
+      combined_options.append(key + '=' + sval)
 
+    return "&".join(combined_options)
 
 
