@@ -14,7 +14,7 @@ class RestRequestClient:
   def make_post_request(self, url, customer_identifier, shared_secret, params):
     """ Makes a HTTP POST request with the proper user information """
     HashedAuthenticator.apply_reverse_guid_and_sign(params, customer_identifier, shared_secret)
-    response = requests.post(url, data=params)
+    response = requests.post(url, data=json.dumps(params), headers={'Content-type': 'application/json', 'Accept': 'application/json'} )
     return response
 
 
